built_modules = list(name for name in
    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;X11Extras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLFunctions;RemoteObjects;SerialPort;Svg;UiTools"
    .split(";"))

shiboken_library_soversion = str(5.15)
pyside_library_soversion = str(5.15)

version = "5.15.12"
version_info = (5, 15, 12, "", "")

__build_date__ = '2026-03-26T17:34:18+00:00'

__build_commit_hash__ = 'b642cfa372ca04f8a09f2bc94f8718ab23911ac1'
__build_commit_hash_described__ = 'v5.15.12-lts-lgpl'

__setup_py_package_version__ = '5.15.12'
